.. octavia documentation master file

=====================
Octavia Documentation
=====================

Welcome to the OpenStack Octavia project documentation. Octavia brings
network load balancing to OpenStack.

See :doc:`reference/introduction` for an overview of Octavia.

For information on what is new see the `Octavia Release Notes <https://docs.openstack.org/releasenotes/octavia/>`_.

.. only:: html

   To align with the overall OpenStack documentation, the Octavia documentation
   is grouped into the following topic areas.

.. toctree::
   :maxdepth: 1

   admin/index.rst
   Octavia API Reference <https://docs.openstack.org/api-ref/load-balancer/>
   cli/index.rst
   configuration/index.rst
   contributor/index.rst
   install/index.rst
   reference/index.rst
   user/index.rst

.. only:: html

   :ref:`search`
